# Command Line Interface

The `abqcy` command line is used to compile you Cython code into an object (`.obj`) file that can be used by Abaqus.
You can use it in the command line or in a Python script with the {py:obj}`abqcy.cli.abqcy` object
(an {py:obj}`abqcy.cli.AbqcyCLI` object).

## References

### The `abqcy` command

```{command-output} abqcy
```

### The `abqcy compile` command

```{command-output} abqcy compile --help
:returncode: 2
```

### The `abqcy run` command

```{command-output} abqcy run --help
:returncode: 2
```
